==> mat_discover-1.3.6.tar.gz: mat_discover-1.3.6/figures/README.md <==
# Figures
Various figures, both interactive and non-interactive, related to the DiSCoVeR algorithm as applied to compounds and clusters. For more details, see [the ChemRXiv paper](https://dx.doi.org/10.33774/chemrxiv-2021-5l2f8).

## Interactive Figures
Compound-wise and cluster-wise interactive figures produced via [Plotly](https://plotly.com/python/).

### Instructions
1. Navigate to [https://sparks-baird.github.io/mat_discover/figures](https://sparks-baird.github.io/mat_discover/figures) (if not already there)
2. Click the corresponding **title** above each image
3. Hover your mouse over datapoints to see more information (e.g. composition, bulk modulus, cluster ID)

Alternatively, you can download the `html` file at [https://github.com/sparks-baird/mat_discover/figures](https://github.com/sparks-baird/mat_discover/figures) and open it in your browser of choice.

### Compound-Wise
#### [Pareto Front Training Contribution to Validation Log Density Proxy](pf-train-contrib-proxy.html)  
<img src="https://sparks-baird.github.io/mat_discover/figures/pf-train-contrib-proxy.png" alt="Pareto Front Training Contribution to Validation Log Density Proxy" width=350>
<hr>

#### [Pareto Front k-Nearest Neighbor Average Proxy](pf-peak-proxy.html)  
<img src="https://sparks-baird.github.io/mat_discover/figures/pf-peak-proxy.png" alt="Pareto Front k-Nearest Neighbor Average Proxy" width=350>
<hr>

#### [Pareto Front Density Proxy (Train and Validation Points)](pf-dens-proxy.html)  
<img src="https://sparks-baird.github.io/mat_discover/figures/pf-dens-proxy.png" alt="Pareto Front Density Proxy (Train and Validation Points)" width=350>
<hr>

### Cluster-Wise
#### [Pareto Front Validation Fraction](pf-frac-proxy.html)  
<img src="https://sparks-baird.github.io/mat_discover/figures/pf-frac-proxy.png" alt="Pareto Front Validation Fraction" width=350>
<hr>

#### [Leave-one-cluster-out Cross-validation k-Nearest Neighbor Average Parity Plot](gcv-pareto.html)  
<img src="https://sparks-baird.github.io/mat_discover/figures/gcv-pareto.png" alt="Leave-one-cluster-out Cross-validation k-Nearest Neighbor Average Parity Plot" width=350>
<hr>

## Non-interactive Figures
The following are non-interactive figures focused on cluster properties and density/target characteristics within DensMAP embedding space.

### Cluster Properties
[Cluster Count Histogram](cluster-count-hist.png)  
<img src="https://sparks-baird.github.io/mat_discover/figures/cluster-count-hist.png" alt="Cluster Count Histogram" width=350>
<hr>
   
[DensMAP Embeddings Colored by Cluster](umap-cluster-scatter.png)  
<img src="https://sparks-baird.github.io/mat_discover/figures/umap-cluster-scatter.png" alt="DensMAP Embeddings Colored by Cluster" width=350>
<hr>
   
### Density and Target Characteristics
[Density Scatter Plot of 2D DensMAP Embeddings](dens-scatter.png)  
<img src="https://sparks-baird.github.io/mat_discover/figures/dens-scatter.png" alt="Density Scatter Plot of 2D DensMAP Embeddings" width=350>
<hr>

[Target Scatter Plot of 2D DensMAP Embeddings](target-scatter.png)  
<img src="https://sparks-baird.github.io/mat_discover/figures/target-scatter.png" alt="Density Scatter Plot of 2D DensMAP Embeddings" width=350>
<hr>

[Density Scatter Plot with Bulk Modulus Overlay in 2D DensMAP Embedding Space](dens-targ-scatter.png)  
<img src="https://sparks-baird.github.io/mat_discover/figures/dens-targ-scatter.png" alt="Density Scatter Plot with Bulk Modulus Overlay in 2D DensMAP Embedding Space" width=350>
<hr>

<!-- 
# Code Graveyard
[Pareto Front Training Contribution to Validation Log Density Proxy](pf-train-contrib-proxy.html)  
![Pareto Front Training Contribution to Validation Log Density Proxy](pf-train-contrib-proxy.png)](pf-train-contrib-proxy.html)

[Pareto Front k-Nearest Neighbor Average Proxy](pf-peak-proxy.html)
[![Pareto Front k-Nearest Neighbor Average Proxy](pf-peak-proxy.png)](pf-peak-proxy.html)

[Pareto Front Density Proxy (Train and Validation Points)](pf-dens-proxy.html)  
[![Pareto Front Density Proxy (Train and Validation Points)](pf-dens-proxy.png)](pf-dens-proxy.html)

[Pareto Front Validation Fraction](pf-frac-proxy.html)
[![Pareto Front Validation Fraction](pf-frac-proxy.png)](pf-frac-proxy.html)

[Leave-one-cluster-out Cross-validation k-Nearest Neighbor Average Parity Plot](gcv-pareto.html)  
[![Leave-one-cluster-out Cross-validation k-Nearest Neighbor Average Parity Plot](gcv-pareto.png)](gcv-pareto.html)
 -->
 
<!--  <a href=*.html>
   <img alt="" src=*.png width=350>
</a> -->

<!-- <img alt="" src=*.png width=350> -->

<!-- <body>
   <a href=pf-train-contrib-proxy.html>
      <img alt="Pareto Front Training Contribution to Validation Log Density Proxy" src=pf-train-contrib-proxy.png width=350>
   </a>
</body> -->

<!-- If you are on the GitHub page (i.e. [https://github.com/sparks-baird/mat_discover/figures](https://github.com/sparks-baird/mat_discover/figures)) and would like to view the interactive figures without downloading the HTML files, please first navigate to [https://sparks-baird.github.io/mat_discover/figures/](https://sparks-baird.github.io/mat_discover/figures/) and then click the image you want to view. -->

==> mat_discover-2.0.1.tar.gz: mat_discover-2.0.1/figures/README.md <==
# Figures

Various figures, both interactive and non-interactive, related to the DiSCoVeR algorithm as applied to compounds and clusters. For more details, see [the ChemRXiv paper](https://dx.doi.org/10.33774/chemrxiv-2021-5l2f8).

## Interactive Figures

Compound-wise and cluster-wise interactive figures produced via [Plotly](https://plotly.com/python/).

### Instructions

1. Navigate to [https://sparks-baird.github.io/mat_discover/figures](https://sparks-baird.github.io/mat_discover/figures) (if not already there)
2. Click the corresponding image
3. Hover your mouse over datapoints to see more information (e.g. composition, bulk modulus, cluster ID)

Alternatively, you can download the `html` file at [https://github.com/sparks-baird/mat_discover/figures](https://github.com/sparks-baird/mat_discover/figures) and open it in your browser of choice.

### Compound-Wise

#### Pareto Front Training Contribution to Validation Log Density Proxy

[<img src="https://sparks-baird.github.io/mat_discover/figures/pf-train-contrib-proxy.png" alt="Pareto Front Training Contribution to Validation Log Density Proxy" width=350>](https://sparks-baird.github.io/mat_discover/figures/pf-train-contrib-proxy.html)
<hr>

#### Pareto Front k-Nearest Neighbor Average Proxy  

[<img src="https://sparks-baird.github.io/mat_discover/figures/pf-peak-proxy.png" alt="Pareto Front k-Nearest Neighbor Average Proxy" width=350>](https://sparks-baird.github.io/mat_discover/figures/pf-peak-proxy.html)
<hr>

#### Pareto Front Density Proxy (Train and Validation Points)

[<img src="https://sparks-baird.github.io/mat_discover/figures/pf-dens-proxy.png" alt="Pareto Front Density Proxy (Train and Validation Points)" width=350>](https://sparks-baird.github.io/mat_discover/figures/pf-dens-proxy.html)
<hr>

### Cluster-Wise

#### Pareto Front Validation Fraction

[<img src="https://sparks-baird.github.io/mat_discover/figures/pf-frac-proxy.png" alt="Pareto Front Validation Fraction" width=350>](https://sparks-baird.github.io/mat_discover/figures/pf-frac-proxy.html)
<hr>

#### Leave-one-cluster-out Cross-validation k-Nearest Neighbor Average Parity Plot

[<img src="https://sparks-baird.github.io/mat_discover/figures/gcv-pareto.png" alt="Leave-one-cluster-out Cross-validation k-Nearest Neighbor Average Parity Plot" width=350>](https://sparks-baird.github.io/mat_discover/figures/gcv-pareto.html)
<hr>

## Non-interactive Figures

The following are non-interactive figures focused on cluster properties and density/target characteristics within DensMAP embedding space.

### Cluster Properties

Cluster Count Histogram  
<img src="https://sparks-baird.github.io/mat_discover/figures/cluster-count-hist.png" alt="Cluster Count Histogram" width=350>
<hr>

DensMAP Embeddings Colored by Cluster  
<img src="https://sparks-baird.github.io/mat_discover/figures/umap-cluster-scatter.png" alt="DensMAP Embeddings Colored by Cluster" width=350>
<hr>

### Density and Target Characteristics

Density Scatter Plot of 2D DensMAP Embeddings  
<img src="https://sparks-baird.github.io/mat_discover/figures/dens-scatter.png" alt="Density Scatter Plot of 2D DensMAP Embeddings" width=350>
<hr>

Target Scatter Plot of 2D DensMAP Embeddings  
<img src="https://sparks-baird.github.io/mat_discover/figures/target-scatter.png" alt="Density Scatter Plot of 2D DensMAP Embeddings" width=350>
<hr>

Density Scatter Plot with Bulk Modulus Overlay in 2D DensMAP Embedding Space  
<img src="https://sparks-baird.github.io/mat_discover/figures/dens-targ-scatter.png" alt="Density Scatter Plot with Bulk Modulus Overlay in 2D DensMAP Embedding Space" width=350>
<hr>

<!-- 
# Code Graveyard
[Pareto Front Training Contribution to Validation Log Density Proxy](pf-train-contrib-proxy.html)  
![Pareto Front Training Contribution to Validation Log Density Proxy](pf-train-contrib-proxy.png)](pf-train-contrib-proxy.html)

[Pareto Front k-Nearest Neighbor Average Proxy](pf-peak-proxy.html)
[![Pareto Front k-Nearest Neighbor Average Proxy](pf-peak-proxy.png)](pf-peak-proxy.html)

[Pareto Front Density Proxy (Train and Validation Points)](pf-dens-proxy.html)  
[![Pareto Front Density Proxy (Train and Validation Points)](pf-dens-proxy.png)](pf-dens-proxy.html)

[Pareto Front Validation Fraction](pf-frac-proxy.html)
[![Pareto Front Validation Fraction](pf-frac-proxy.png)](pf-frac-proxy.html)

[Leave-one-cluster-out Cross-validation k-Nearest Neighbor Average Parity Plot](gcv-pareto.html)  
[![Leave-one-cluster-out Cross-validation k-Nearest Neighbor Average Parity Plot](gcv-pareto.png)](gcv-pareto.html)
 -->

<!--  <a href=*.html>
   <img alt="" src=*.png width=350>
</a> -->

<!-- <img alt="" src=*.png width=350> -->

<!-- <body>
   <a href=pf-train-contrib-proxy.html>
      <img alt="Pareto Front Training Contribution to Validation Log Density Proxy" src=pf-train-contrib-proxy.png width=350>
   </a>
</body> -->

<!-- If you are on the GitHub page (i.e. [https://github.com/sparks-baird/mat_discover/figures](https://github.com/sparks-baird/mat_discover/figures)) and would like to view the interactive figures without downloading the HTML files, please first navigate to [https://sparks-baird.github.io/mat_discover/figures/](https://sparks-baird.github.io/mat_discover/figures/) and then click the image you want to view. -->
